'use strict';

var view = require('@codemirror/view');
var language = require('@codemirror/language');
var highlight = require('@lezer/highlight');

const dark0 = '#3c3836', dark1 = '#504945', dark2 = '#665c54', dark3 = '#7c6f64', gray_244 = '#928374', light0 = '#fbf1c7', light1 = '#ebdbb2', light2 = '#bdae93', faded_red = '#9d0006', faded_green = '#79740e', faded_yellow = '#b57614', faded_blue = '#076678', faded_purple = '#8f3f71', faded_aqua = '#427b58', faded_orange = '#af3a03';
const bg0 = light0, bg1 = light1, bg2 = light2, gray = gray_244, fg0 = dark0, fg1 = dark1, fg2 = dark2, fg3 = dark3, red = faded_red, green = faded_green, yellow = faded_yellow, blue = faded_blue, purple = faded_purple, aqua = faded_aqua, orange = faded_orange;
const invalid = red, darkBackground = bg1, highlightBackground = '#ffc42e52', background = bg0, tooltipBackground = bg1, selection = darkBackground, selectionMatch = '#ffc42e', cursor = orange;
/**
The editor theme styles for Gruvbox Light.
*/
const gruvboxLightTheme = view.EditorView.theme({
    '&': {
        color: fg0,
        backgroundColor: background,
    },
    '.cm-content': {
        caretColor: cursor,
    },
    '.cm-cursor, .cm-dropCursor': { borderLeftColor: cursor },
    '&.cm-focused > .cm-scroller > .cm-selectionLayer .cm-selectionBackground, .cm-selectionBackground, .cm-content ::selection': { backgroundColor: selection },
    '.cm-panels': { backgroundColor: darkBackground, color: fg0 },
    '.cm-panels.cm-panels-top': { borderBottom: '2px solid black' },
    '.cm-panels.cm-panels-bottom': { borderTop: '2px solid black' },
    '.cm-searchMatch': {
        backgroundColor: highlightBackground,
        color: yellow,
        outline: `1px solid ${bg2}`,
    },
    '.cm-searchMatch.cm-searchMatch-selected': {
        backgroundColor: selectionMatch,
    },
    '.cm-activeLine': { backgroundColor: highlightBackground },
    '.cm-selectionMatch': { backgroundColor: bg2 },
    '&.cm-focused .cm-matchingBracket, &.cm-focused .cm-nonmatchingBracket': {
        outline: `1px solid ${bg2}`,
        fontStyle: 'bold',
    },
    '&.cm-focused .cm-matchingBracket': {
        backgroundColor: bg2,
    },
    '.cm-gutters': {
        backgroundColor: bg1,
        color: fg2,
        border: 'none',
    },
    '.cm-activeLineGutter': {
        backgroundColor: selectionMatch,
    },
    '.cm-foldPlaceholder': {
        backgroundColor: 'transparent',
        border: 'none',
        color: '#ddd',
    },
    '.cm-tooltip': {
        border: 'none',
        backgroundColor: tooltipBackground,
    },
    '.cm-tooltip .cm-tooltip-arrow:before': {
        borderTopColor: 'transparent',
        borderBottomColor: 'transparent',
    },
    '.cm-tooltip .cm-tooltip-arrow:after': {
        borderTopColor: tooltipBackground,
        borderBottomColor: tooltipBackground,
    },
    '.cm-tooltip-autocomplete': {
        '& > ul > li[aria-selected]': {
            backgroundColor: highlightBackground,
            color: fg1,
        },
    },
}, { dark: false });
/**
The highlighting style for code in the Gruvbox Light theme.
*/
const gruvboxLightHighlightStyle = language.HighlightStyle.define([
    { tag: highlight.tags.keyword, color: red },
    {
        tag: [highlight.tags.name, highlight.tags.deleted, highlight.tags.character, highlight.tags.propertyName, highlight.tags.macroName],
        color: aqua,
    },
    { tag: [highlight.tags.variableName], color: blue },
    { tag: [highlight.tags.function(highlight.tags.variableName)], color: green, fontStyle: 'bold' },
    { tag: [highlight.tags.labelName], color: fg0 },
    {
        tag: [highlight.tags.color, highlight.tags.constant(highlight.tags.name), highlight.tags.standard(highlight.tags.name)],
        color: purple,
    },
    { tag: [highlight.tags.definition(highlight.tags.name), highlight.tags.separator], color: fg0 },
    { tag: [highlight.tags.brace], color: fg0 },
    {
        tag: [highlight.tags.annotation],
        color: invalid,
    },
    {
        tag: [highlight.tags.number, highlight.tags.changed, highlight.tags.annotation, highlight.tags.modifier, highlight.tags.self, highlight.tags.namespace],
        color: purple,
    },
    {
        tag: [highlight.tags.typeName, highlight.tags.className],
        color: yellow,
    },
    {
        tag: [highlight.tags.operator, highlight.tags.operatorKeyword],
        color: red,
    },
    {
        tag: [highlight.tags.tagName],
        color: aqua,
        fontStyle: 'bold',
    },
    {
        tag: [highlight.tags.squareBracket],
        color: orange,
    },
    {
        tag: [highlight.tags.angleBracket],
        color: blue,
    },
    {
        tag: [highlight.tags.attributeName],
        color: aqua,
    },
    {
        tag: [highlight.tags.regexp],
        color: aqua,
    },
    {
        tag: [highlight.tags.quote],
        color: gray,
    },
    { tag: [highlight.tags.string], color: fg0 },
    {
        tag: highlight.tags.link,
        color: fg3,
        textDecoration: 'underline',
        textUnderlinePosition: 'under',
    },
    {
        tag: [highlight.tags.url, highlight.tags.escape, highlight.tags.special(highlight.tags.string)],
        color: purple,
    },
    { tag: [highlight.tags.meta], color: yellow },
    { tag: [highlight.tags.comment], color: gray, fontStyle: 'italic' },
    { tag: highlight.tags.strong, fontWeight: 'bold', color: orange },
    { tag: highlight.tags.emphasis, fontStyle: 'italic', color: green },
    { tag: highlight.tags.strikethrough, textDecoration: 'line-through' },
    { tag: highlight.tags.heading, fontWeight: 'bold', color: green },
    { tag: [highlight.tags.heading1, highlight.tags.heading2], fontWeight: 'bold', color: green },
    {
        tag: [highlight.tags.heading3, highlight.tags.heading4],
        fontWeight: 'bold',
        color: yellow,
    },
    {
        tag: [highlight.tags.heading5, highlight.tags.heading6],
        color: yellow,
    },
    { tag: [highlight.tags.atom, highlight.tags.bool, highlight.tags.special(highlight.tags.variableName)], color: purple },
    {
        tag: [highlight.tags.processingInstruction, highlight.tags.inserted],
        color: blue,
    },
    {
        tag: [highlight.tags.contentSeparator],
        color: red,
    },
    { tag: highlight.tags.invalid, color: orange, borderBottom: `1px dotted ${invalid}` },
]);
/**
Extension to enable the Gruvbox Light theme (both the editor theme and
the highlight style).
*/
const gruvboxLight = [
    gruvboxLightTheme,
    language.syntaxHighlighting(gruvboxLightHighlightStyle),
];

exports.gruvboxLight = gruvboxLight;
exports.gruvboxLightHighlightStyle = gruvboxLightHighlightStyle;
exports.gruvboxLightTheme = gruvboxLightTheme;
